const componentReferences = {};
export function setComponentReferences(ts, node, moduleDoc) {
    if (node.kind !== ts.SyntaxKind.ClassDeclaration) {
        return;
    }
    const references = getReferences(node);
    updateReferences(references, node, moduleDoc);
}
export function getReferencesByComponent(componentName) {
    return componentReferences[componentName] ?? [];
}
function getReferences(node) {
    const docs = getDocsByTagName(node, "reference");
    return docs
        ?.map((tags) => tags?.map((doc) => {
        const values = doc?.comment.split(/ - (.*)/s);
        if (values && values.length > 1) {
            return {
                name: values[0].trim(),
                url: values[1].trim(),
            };
        }
    }))
        .flat();
}
function updateReferences(references, node, moduleDoc) {
    if (!references?.length) {
        return;
    }
    const className = node.name.getText();
    const component = moduleDoc?.declarations?.find((dec) => dec.name === className);
    componentReferences[component.name] = references;
}
function getDocsByTagName(node, tagName) {
    return node?.jsDoc?.map((doc) => doc?.tags?.filter((tag) => tag?.tagName?.getText() === tagName));
}
